@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
+from chb._imports import *
 
-from ._imports import *
+from chb._log import Log
 
 log = Log()()
 
